==> v2.12.14.zip: pkg-component-builder/README.md <==
# Component Builder Package (v2.12.14)

The Joomla Component Builder Package that bundles JCB Component and all the plugins and features available into one package for easy install and update of your JCB system.

## Details

- Packager: [Vast Development Method](https://dev.vdm.io/)
- Author: [Llewellyn van der Merwe](http://www.joomlacomponentbuilder.com/)
- Creation Date: December 2021
- Max Joomla Version: J3.10
- Minimum Joomla Version: J3.8

## Extensions

- [joomla/Component-Builder](https://git.vdm.dev/joomla/Component-Builder) [v2.12.14](https://git.vdm.dev/joomla/Component-Builder/archive/v2.12.14.zip)
> Adds gitea URL. Adds option to add changelog gh-813. Adds clone option to some areas. Fixed gh-784 to allow BASE64 filter selection.
- [joomla/plg_content_componentbuilderadminheaderstabs](https://git.vdm.dev/joomla/plg_content_componentbuilderadminheaderstabs) [v1.0.1](https://git.vdm.dev/attachments/8bb051d0-947f-4849-9659-0145918543ab)
> Plugin for adding header code to admin area - tabs (2021-10-01)
- [joomla/plg_content_componentbuildercomponentheaderstabs](https://git.vdm.dev/joomla/plg_content_componentbuildercomponentheaderstabs) [v1.0.0](https://git.vdm.dev/attachments/f919fc1d-9e2b-4f80-8ac6-c49f651d7c47)
> Plugin for adding header code to your component - tabs (2021-08-01)
- [joomla/plg_content_componentbuildercustomadminheaderstabs](https://git.vdm.dev/joomla/plg_content_componentbuildercustomadminheaderstabs) [v1.0.1](https://git.vdm.dev/attachments/1813dcf5-b5d3-4e8e-ab41-e95acde4808a)
> Plugin for adding header code to custom admin area - tabs (2021-10-01)
- [joomla/plg_content_componentbuilderfieldorderingtabs](https://git.vdm.dev/joomla/plg_content_componentbuilderfieldorderingtabs) [v1.0.0](https://git.vdm.dev/attachments/c50ac20b-21b6-483a-88fb-33ffc974577a)
> Plugin for changing default ordering in admin views - tabs (2021-03-01)
- [joomla/plg_content_componentbuilderlanguagetabs](https://git.vdm.dev/joomla/plg_content_componentbuilderlanguagetabs) [v1.0.0](https://git.vdm.dev/attachments/6b8aa006-0172-422e-9003-f87283c3fe87)
> Plugin for language packaging - tabs (2020-01-01)
- [joomla/plg_content_componentbuilderprivacytabs](https://git.vdm.dev/joomla/plg_content_componentbuilderprivacytabs) [v1.0.0](https://git.vdm.dev/attachments/d4120956-8b7b-4919-a56e-e5d50b85e90b)
> Plugin to integrate privacy suite - tabs (2020-11-01)
- [joomla/plg_content_componentbuildersiteheaderstabs](https://git.vdm.dev/joomla/plg_content_componentbuildersiteheaderstabs) [v1.0.0](https://git.vdm.dev/attachments/653a0082-2292-4408-bb3a-c6acd13d7ff9)
> Plugin for adding header code to site area - tabs (2021-06-01)
- [joomla/plg_extension_componentbuilderactionlogcompiler](https://git.vdm.dev/joomla/plg_extension_componentbuilderactionlogcompiler) [v1.0.2](https://git.vdm.dev/attachments/3f26a81f-6996-46ce-8670-a5eee9b50056)
> Plugin for adding action log integration to your components - compiler (2020-12-01)
- [joomla/plg_extension_componentbuilderexportcompiler](https://git.vdm.dev/joomla/plg_extension_componentbuilderexportcompiler) [v1.0.1](https://git.vdm.dev/attachments/2c6cb391-a063-4e6f-8188-0a98e908084a)
> Plugin to improve the export feature - compiler (2021-03-01)
- [joomla/plg_extension_componentbuilderfieldorderingcompiler](https://git.vdm.dev/joomla/plg_extension_componentbuilderfieldorderingcompiler) [v1.0.0](https://git.vdm.dev/attachments/77a42f07-f2cf-49ae-ba53-b016b8e28db6)
> Plugin for changing default ordering in admin views - compiler (2021-03-01)
- [joomla/plg_extension_componentbuilderheaderscompiler](https://git.vdm.dev/joomla/plg_extension_componentbuilderheaderscompiler) [v1.0.5](https://git.vdm.dev/attachments/dbdff6de-6af0-455f-b218-c307fbe816ab)
> Plugin for adding header code to your component - compiler (2021-10-01)
- [joomla/plg_extension_componentbuilderlanguagepackaging](https://git.vdm.dev/joomla/plg_extension_componentbuilderlanguagepackaging) [v1.0.0](https://git.vdm.dev/attachments/928d0a35-527a-4acd-91fa-d10cdfc4669c)
> Plugin for language packaging - compiler (2020-01-01)
- [joomla/plg_extension_componentbuilderprivacycompiler](https://git.vdm.dev/joomla/plg_extension_componentbuilderprivacycompiler) [v1.0.0](https://git.vdm.dev/attachments/d803d1a3-4a4c-4fc4-b7b9-b1454ddb00ab)
> Plugin to integrate privacy suite - compiler (2020-11-01)

### Copyright (2015)
> Copyright (C) 2015 Llewellyn van der Merwe. All rights reserved.
### License
> GNU General Public License version 2; see LICENSE

==> v2.13.0.zip: pkg-component-builder/README.md <==
# Component Builder Package (v2.13.0)

The Joomla Component Builder Package that bundles JCB Component and all the plugins and features available into one package for easy install and update of your JCB system.

## Details

- Packager: [Vast Development Method](https://dev.vdm.io/)
- Author: [Llewellyn van der Merwe](http://www.joomlacomponentbuilder.com/)
- Creation Date: May 2022
- Max Joomla Version: J3.10
- Minimum Joomla Version: J3.8

## Extensions

- [joomla/Component-Builder](https://git.vdm.dev/joomla/Component-Builder) [v2.13.0](https://git.vdm.dev/joomla/Component-Builder/archive/v2.13.0.zip)
> Native MVC
- [joomla/plg_content_componentbuilderadminheaderstabs](https://git.vdm.dev/joomla/plg_content_componentbuilderadminheaderstabs) [v1.0.1](https://git.vdm.dev/attachments/8bb051d0-947f-4849-9659-0145918543ab)
> Plugin for adding header code to admin area - tabs (2021-10-01)
- [joomla/plg_content_componentbuildercomponentheaderstabs](https://git.vdm.dev/joomla/plg_content_componentbuildercomponentheaderstabs) [v1.0.0](https://git.vdm.dev/attachments/f919fc1d-9e2b-4f80-8ac6-c49f651d7c47)
> Plugin for adding header code to your component - tabs (2021-08-01)
- [joomla/plg_content_componentbuildercustomadminheaderstabs](https://git.vdm.dev/joomla/plg_content_componentbuildercustomadminheaderstabs) [v1.0.1](https://git.vdm.dev/attachments/1813dcf5-b5d3-4e8e-ab41-e95acde4808a)
> Plugin for adding header code to custom admin area - tabs (2021-10-01)
- [joomla/plg_content_componentbuilderfieldorderingtabs](https://git.vdm.dev/joomla/plg_content_componentbuilderfieldorderingtabs) [v1.0.0](https://git.vdm.dev/attachments/c50ac20b-21b6-483a-88fb-33ffc974577a)
> Plugin for changing default ordering in admin views - tabs (2021-03-01)
- [joomla/plg_content_componentbuilderlanguagetabs](https://git.vdm.dev/joomla/plg_content_componentbuilderlanguagetabs) [v1.0.0](https://git.vdm.dev/attachments/6b8aa006-0172-422e-9003-f87283c3fe87)
> Plugin for language packaging - tabs (2020-01-01)
- [joomla/plg_content_componentbuilderprivacytabs](https://git.vdm.dev/joomla/plg_content_componentbuilderprivacytabs) [v1.0.0](https://git.vdm.dev/attachments/d4120956-8b7b-4919-a56e-e5d50b85e90b)
> Plugin to integrate privacy suite - tabs (2020-11-01)
- [joomla/plg_content_componentbuildersiteheaderstabs](https://git.vdm.dev/joomla/plg_content_componentbuildersiteheaderstabs) [v1.0.0](https://git.vdm.dev/attachments/653a0082-2292-4408-bb3a-c6acd13d7ff9)
> Plugin for adding header code to site area - tabs (2021-06-01)
- [joomla/plg_extension_componentbuilderactionlogcompiler](https://git.vdm.dev/joomla/plg_extension_componentbuilderactionlogcompiler) [v1.0.2](https://git.vdm.dev/attachments/3f26a81f-6996-46ce-8670-a5eee9b50056)
> Plugin for adding action log integration to your components - compiler (2020-12-01)
- [joomla/plg_extension_componentbuilderexportcompiler](https://git.vdm.dev/joomla/plg_extension_componentbuilderexportcompiler) [v1.0.1](https://git.vdm.dev/attachments/2c6cb391-a063-4e6f-8188-0a98e908084a)
> Plugin to improve the export feature - compiler (2021-03-01)
- [joomla/plg_extension_componentbuilderfieldorderingcompiler](https://git.vdm.dev/joomla/plg_extension_componentbuilderfieldorderingcompiler) [v1.0.0](https://git.vdm.dev/attachments/77a42f07-f2cf-49ae-ba53-b016b8e28db6)
> Plugin for changing default ordering in admin views - compiler (2021-03-01)
- [joomla/plg_extension_componentbuilderheaderscompiler](https://git.vdm.dev/joomla/plg_extension_componentbuilderheaderscompiler) [v1.0.5](https://git.vdm.dev/attachments/dbdff6de-6af0-455f-b218-c307fbe816ab)
> Plugin for adding header code to your component - compiler (2021-10-01)
- [joomla/plg_extension_componentbuilderlanguagepackaging](https://git.vdm.dev/joomla/plg_extension_componentbuilderlanguagepackaging) [v1.0.0](https://git.vdm.dev/attachments/928d0a35-527a-4acd-91fa-d10cdfc4669c)
> Plugin for language packaging - compiler (2020-01-01)
- [joomla/plg_extension_componentbuilderprivacycompiler](https://git.vdm.dev/joomla/plg_extension_componentbuilderprivacycompiler) [v1.0.0](https://git.vdm.dev/attachments/d803d1a3-4a4c-4fc4-b7b9-b1454ddb00ab)
> Plugin to integrate privacy suite - compiler (2020-11-01)

### Copyright (2015)
> Copyright (C) 2015 Llewellyn van der Merwe. All rights reserved.
### License
> GNU General Public License version 2; see LICENSE
